@@ -1,9 +1,9 @@
 package DBIx::SchemaChecksum::App;
 use 5.010;
-use MooseX::App 1.21 qw(Config);
+use MooseX::App 1.21 qw(Config ConfigHome);
 extends qw(DBIx::SchemaChecksum);
 
-# ABSTRACT: App base class
+# ABSTRACT: Manage your datebase schema via checksums
 
 use DBI;
 
@@ -46,11 +46,27 @@ __END__
 
 =head1 NAME
 
-DBIx::SchemaChecksum::App - App base class
+DBIx::SchemaChecksum::App - Manage your datebase schema via checksums
 
 =head1 VERSION
 
-version 1.006
+version 1.100
+
+=head1 DESCRIPTION
+
+Manage your datebase schema via checksums
+
+=over
+
+=item * Use C<checksum> to calculate the current checksum of your database.
+
+=item * Use C<new_changes_file> to generate a new db update script based on the current checksum.
+
+=item * Use C<apply_changes> to apply all update scripts starting from the current checksum.
+
+=back
+
+For more background information, check out the man-page via C<perldoc DBIx::SchemaChecksum> or on L<https://metacpan.org/pod/DBIx::SchemaChecksum>
 
 =head1 AUTHORS
 
